@@ -1,6 +1,6 @@
 # iban.py - functions for handling International Bank Account Numbers (IBANs)
 #
-# Copyright (C) 2011, 2012 Arthur de Jong
+# Copyright (C) 2011, 2012, 2013 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -27,10 +27,10 @@ for the remainder of the number.
 Some countries may also use checksum algorithms within their number but
 this is currently not checked by this number.
 
->>> is_valid('GR16 0110 1050 0000 1054 7023 795')
-True
->>> is_valid('BE31435411161155')
-True
+>>> validate('GR16 0110 1050 0000 1054 7023 795')
+'GR1601101050000010547023795'
+>>> validate('BE31435411161155')
+'BE31435411161155'
 >>> compact('GR16 0110 1050 0000 1054 7023 795')
 'GR1601101050000010547023795'
 >>> format('GR1601101050000010547023795')
@@ -40,6 +40,7 @@ True
 import re
 
 from stdnum import numdb
+from stdnum.exceptions import *
 from stdnum.iso7064 import mod_97_10
 from stdnum.util import clean
 
@@ -60,7 +61,7 @@ def compact(number):
     return clean(number, ' -').strip().upper()
 
 
-def _convert(number):
+def _to_base10(number):
     """Prepare the number to it's base10 representation (also moving the
     check digits to the end) so it can be checked with the ISO 7064
     Mod 97, 10 algorithm."""
@@ -68,35 +69,44 @@ def _convert(number):
     return ''.join(str(_alphabet.index(x)) for x in number[4:] + number[:4])
 
 
-def _matches_structure(number, structure):
-    """Check the supplied number against the supplied structure."""
-    start = 0
-    for length, code in _struct_re.findall(structure):
-        length = int(length)
-        if code == 'n' and not number[start:start + length].isdigit():
-            return False
-        elif code == 'a' and not number[start:start + length].isalpha():
-            return False
-        elif code == 'c' and not number[start:start + length].isalnum():
-            return False  # pragma: no cover (due to checksum check)
-        start += length
-    # the whole number should be parsed now
-    return start == len(number)
+def _struct_to_re(structure):
+    """Convert an IBAN structure to a refular expression that can be used
+    to validate the number."""
+    def conv(match):
+        chars = {
+            'n': '[0-9]',
+            'a': '[A-Z]',
+            'c': '[A-Za-z0-9]',
+        }[match.group(2)]
+        return '%s{%s}' % (chars, match.group(1))
+    return re.compile('^%s$' % _struct_re.sub(conv, structure))
+
+
+def validate(number):
+    """Checks to see if the number provided is a valid IBAN."""
+    number = compact(number)
+    try:
+        test_number = _to_base10(number)
+    except:
+        raise InvalidFormat()
+    # ensure that checksum is valid
+    mod_97_10.validate(test_number)
+    # look up the number
+    info = _ibandb.info(number)
+    # check if the bban part of number has the correct structure
+    bban = number[4:]
+    if not _struct_to_re(info[0][1].get('bban', '')).match(bban):
+        raise InvalidFormat()
+    # return the compact representation
+    return number
 
 
 def is_valid(number):
     """Checks to see if the number provided is a valid IBAN."""
     try:
-        number = compact(number)
-        # ensure that checksum is valid
-        if not mod_97_10.is_valid(_convert(number)):
-            return False
-    except:
+        return bool(validate(number))
+    except ValidationError:
         return False
-    # look up the number
-    info = _ibandb.info(number)
-    # check if the number has the correct structure
-    return _matches_structure(number[4:], info[0][1].get('bban', ''))
 
 
 def format(number, separator=' '):
