@@ -1,4 +1,4 @@
-# mod_11_2.py - functions for performing the ISO 7064 Mod 11, 2 algorithm
+# mod_37_2.py - functions for performing the ISO 7064 Mod 37, 2 algorithm
 #
 # Copyright (C) 2010, 2011, 2012, 2013 Arthur de Jong
 #
@@ -17,48 +17,52 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""The ISO 7064 Mod 11, 2 algorithm.
+"""The ISO 7064 Mod 37, 2 algorithm.
 
-The Mod 11, 2 algorithm is a simple module 11 checksum where the check
-digit can be an X to make the number valid.
+The Mod 37, 2 checksum can be used for alphanumeric numbers and the check
+digit may also be numeric, a letter or '*'.
 
-For a module that can do generic Mod x, 2 calculations see the
-:mod:`stdnum.iso7064.mod_37_2` module.
+>>> calc_check_digit('G123489654321')
+'Y'
+>>> validate('G123489654321Y')
+'G123489654321Y'
+>>> checksum('G123489654321Y')
+1
 
->>> calc_check_digit('0794')
-'0'
->>> validate('07940')
-'07940'
->>> calc_check_digit('079')
+By changing the alphabet this can be turned into any Mod x, 2
+algorithm. For example Mod 11, 2:
+
+>>> calc_check_digit('079', alphabet='0123456789X')
 'X'
->>> validate('079X')
+>>> validate('079X', alphabet='0123456789X')
 '079X'
->>> checksum('079X')
+>>> checksum('079X', alphabet='0123456789X')
 1
 """
 
 from stdnum.exceptions import *
 
 
-def checksum(number):
+def checksum(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ*'):
     """Calculate the checksum. A valid number should have a checksum of 1."""
+    modulus = len(alphabet)
     check = 0
     for n in number:
-        check = (2 * check + int(10 if n == 'X' else n)) % 11
+        check = (2 * check + alphabet.index(n)) % modulus
     return check
 
 
-def calc_check_digit(number):
+def calc_check_digit(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ*'):
     """With the provided number, calculate the extra digit that should be
     appended to make it a valid number."""
-    c = (1 - 2 * checksum(number)) % 11
-    return 'X' if c == 10 else str(c)
+    modulus = len(alphabet)
+    return alphabet[(1 - 2 * checksum(number, alphabet)) % modulus]
 
 
-def validate(number):
+def validate(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ*'):
     """Checks whether the check digit is valid."""
     try:
-        valid = checksum(number) == 1
+        valid = checksum(number, alphabet) == 1
     except:
         raise InvalidFormat()
     if not valid:
@@ -66,9 +70,9 @@ def validate(number):
     return number
 
 
-def is_valid(number):
+def is_valid(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ*'):
     """Checks whether the check digit is valid."""
     try:
-        return bool(validate(number))
+        return bool(validate(number, alphabet))
     except ValidationError:
         return False
